@@ -184,7 +184,7 @@ class Bot:
                 self.last_response = response
                 self.last_json_response = json.loads(response.text)
                 if self.last_json_response['message'] == 'challenge_required':
-                    raise ChallengeRequiredException('Challenge required')
+                    raise ChallengeRequiredException('Challenge required:')
                 if (self.debug):
                     log.info(f'RESPONSE: {str(self.last_json_response)}')
             except SentryBlockException:
